@@ -73,7 +73,7 @@ def fondasms_handler(request, **options):
     except Exception as e:
         logger.error("Exception in request processing ({action}) : "
                      "{excp}".format(action=action, excp=e))
-        logger.debug("\n".join(traceback.format_stack()))
+        logger.debug("".join(traceback.format_stack()))
         response = {'error': {'message': str(e)}}
         return HttpResponse(json.dumps(response),
                             content_type='application/json',
